@@ -6,21 +6,26 @@ from mezzanine.conf import settings
 from mezzanine.core.fields import FileField
 from mezzanine.core.models import Displayable, Ownable, RichText, Slugged
 from mezzanine.generic.fields import CommentsField, RatingField
+from mezzanine.utils.models import AdminThumbMixin
 
 
-class BlogPost(Displayable, Ownable, RichText):
+class BlogPost(Displayable, Ownable, RichText, AdminThumbMixin):
     """
     A blog post.
     """
 
-    categories = models.ManyToManyField("BlogCategory", blank=True,
-                                        related_name="blogposts")
-    allow_comments = models.BooleanField(default=True)
+    categories = models.ManyToManyField("BlogCategory",
+                                        verbose_name=_("Categories"),
+                                        blank=True, related_name="blogposts")
+    allow_comments = models.BooleanField(verbose_name=_("Allow comments"),
+                                         default=True)
     comments = CommentsField(verbose_name=_("Comments"))
     rating = RatingField(verbose_name=_("Rating"))
     featured_image = FileField(verbose_name=_("Featured Image"), null=True,
                                upload_to="blog", max_length=255, blank=True)
 
+    admin_thumb_field = "featured_image"
+
     class Meta:
         verbose_name = _("Blog post")
         verbose_name_plural = _("Blog posts")
